@@ -48,9 +48,24 @@ class MiddleDatasetMgmt(dsmgmt.DatasetMgmt):
         with blob.open("r") as f:
             metadata_list = json.loads(f.read())
         return metadata_list
-
+    
+    
+    def _parse_image_function(self, example_proto):   
+        return tf.io.parse_single_example(example_proto, self._image_feature_description)
+    
+    
+    _image_feature_description = {
+        'image': tf.io.FixedLenFeature([], tf.string),
+        'segmentation_mask':tf.io.FixedLenFeature([], tf.string),
+    }
+    
+    def _augmentation(self, image, segmentation_mask):
+        image_aug = tf.image.flip_left_right(image)
+        segmentation_mask_aug = tf.image.flip_left_right(segmentation_mask)
+        return image_aug, segmentation_mask_aug
     
     ###
+    
     def make_bucket(self, bucket_name):
         self.log.info(f"{sys._getframe(0).f_code.co_name} function called")
         
@@ -77,18 +92,20 @@ class MiddleDatasetMgmt(dsmgmt.DatasetMgmt):
     
     
     ###
+    
     def read(self, bucket_name): #TFRecord format
         self.log.info("under contruction")
     
     
-    def read_and_split(self, bucket_name, dataset_size, data_split): #TFRecord format : storing a sequence of binary records
+    #dataset_begin_idx는 raw dataset source가 다른 것을 적용하는 시점에는 반듯이 삭제해야 함 
+    def read_and_split(self, bucket_name, dataset_begin_idx, dataset_size, data_split): #TFRecord format : storing a sequence of binary records
         test_set = []
         train_val_set = []
         
         bucket = self.client.get_bucket(bucket_name)
         metadata_list = self._get_dataset_metadata(bucket)
         
-        for metadata in metadata_list[:dataset_size]:
+        for metadata in metadata_list[dataset_begin_idx:dataset_size]:
             blob = bucket.blob(metadata[self.gv.DATASET_METADATA_KEY_SOURCE_REF]) 
             with blob.open("rb") as f:
                 image_bytes = f.read()
@@ -114,10 +131,34 @@ class MiddleDatasetMgmt(dsmgmt.DatasetMgmt):
             for tf_example in dataset:
                 writer.write(tf_example.SerializeToString())
                 
+    
+    def read_images(self, path):  #TFRecord format
+        image_dataset = tf.data.TFRecordDataset(path, self.gv.DATASET_COMPRESS_TYPE)
+        assert isinstance(image_dataset, tf.data.Dataset)
+        parsed_image_dataset = image_dataset.map(self._parse_image_function)
+        return parsed_image_dataset
+        
+        # with tf.data.TFRecordDataset(path, self.gv.DATASET_COMPRESS_TYPE) as image_dataset:
+        #     return image_dataset.map(_parse_image_function)
                 
-                
+        
+    def augmente_image(self, parsed_image_dataset):
+        train_aug_set = []
+        for image_features in parsed_image_dataset:
+            img = image_features['image']
+            segment_img = image_features['segmentation_mask']
+
+            train_aug_set.append(self._make_example(img, segment_img))
+
+            image_aug, segmentation_mask_aug = self._augmentation(tf.io.decode_image(img, channels=3), tf.io.decode_png(segment_img, channels=1))
+            train_aug_set.append(self._make_example(tf.io.encode_jpeg(image_aug), tf.io.encode_png(segmentation_mask_aug)))
+            
+        return train_aug_set
 
 
+                
+
+# Download, Upload to GCS
 class TensorflowDatasetMgmt(MiddleDatasetMgmt):
     
     def download(self, dataset_name):
@@ -160,6 +201,7 @@ class TensorflowDatasetMgmt(MiddleDatasetMgmt):
         blob.upload_from_string(json.dumps(dataset_list))
     
     
+# Download, Upload to GCS   
 class COCODatasetMgmt(MiddleDatasetMgmt):
     
     def download(self, dataset_name):
