@@ -41,6 +41,7 @@ class Storage():
     def activate_tensorflow_dataset_mgmt(self):
         self.dsmgmt = self.dsmgmt_module.TensorflowDatasetMgmt(self.gv, self.log)
         
+        
     def activate_coco_dataset_mgmt(self):
         self.dsmgmt = self.dsmgmt_module.COCODatasetMgmt(self.gv, self.log)
 
@@ -64,9 +65,17 @@ class Storage():
         self.dsmgmt.upload(bucket_name)
 
         
-    def read_and_split_dataset(self, bucket_name, dataset_size, data_split):
-        return self.dsmgmt.read_and_split(bucket_name, dataset_size, data_split)
+    def read_and_split_dataset(self, bucket_name, dataset_begin_idx, dataset_size, data_split):
+        return self.dsmgmt.read_and_split(bucket_name, dataset_begin_idx, dataset_size, data_split)
 
         
     def write_dataset(self, path, dataset): 
-        self.dsmgmt.write(path, dataset)
\ No newline at end of file
+        self.dsmgmt.write(path, dataset)
+        
+        
+    def read_images(self, path):
+        return self.dsmgmt.read_images(path)
+    
+    
+    def augmentation(self, image_dataset):
+        return self.dsmgmt.augmente_image(image_dataset)
\ No newline at end of file
