@@ -24,7 +24,7 @@ class GlobalVariable(Artifact):
             self.SERVING_CONTAINER_URI = f"{self.CONTAINER_URI_PREFIX}/{self.PROJECT_ID}/{self.SERVING_CONTAINER_URI_POSTFIX}"
             cls._init = True
             print(f"PROJECT_ID={self.PROJECT_ID}\nSERVICE_ACCOUNT_ID={self.SERVICE_ACCOUNT_ID}")
-            print(f"COMPONENT_CONTAINER_URI={self.COMPONENT_CONTAINER_URI}\nTRAIN_CONTAINER_URI={self.nTRAIN_CONTAINER_URI}\nSERVING_CONTAINER_URI={self.SERVING_CONTAINER_URI}")
+            print(f"COMPONENT_CONTAINER_URI={self.COMPONENT_CONTAINER_URI}\nTRAIN_CONTAINER_URI={self.TRAIN_CONTAINER_URI}\nSERVING_CONTAINER_URI={self.SERVING_CONTAINER_URI}")
     
     VERSION = "0.0.3"
     PROJECT_ID = ""
@@ -64,7 +64,7 @@ class GlobalVariable(Artifact):
     EXPERIMENT_DESCRIPTION = "Pet Segmentation Experiment"
     
     #############
-    DATASET_BUCKET = 'oxford_iiit_pet_3_2_0_rgb'
+    DATASET_BUCKET = ['oxford_iiit_pet_3_2_0_rgb', 'oxford_iiit_pet_lsm']
     #DATASET_BUCKET = 'oxford_iiit_pet_lsm'
 
     DATASET_BUCKET2 = 'oxford_iiit_pet_lsm' #'oxford_iiit_pet_3_2_0_rgb'
